import * as React from 'react';
import { IconNext, IconPrev, MonthsDropdown, YearsDropdown } from '../../components';
import { useDayPicker, useNavigation } from '../../hooks';
import { getPrevNextMonths } from '../../hooks/useNavigation/utils/getPrevNextMonths';
import { UIElement as UI } from '../../types';
/**
 * Render the caption of a month, which includes title and navigation buttons.
 * The caption has a different layout when setting the `numberOfMonths` prop.
 */
export function Caption(props) {
    var displayMonth = props.displayMonth, isFirst = props.isFirst, isLast = props.isLast, isBetween = props.isBetween;
    var context = useDayPicker();
    var dir = context.dir, locale = context.locale, classNames = context.classNames, numberOfMonths = context.numberOfMonths, disableNavigation = context.disableNavigation, styles = context.styles, captionLayout = context.captionLayout, _a = context.labels, labelPrev = _a.labelPrev, labelNext = _a.labelNext, formatCaption = context.formatters.formatCaption, onMonthChange = context.onMonthChange;
    var _b = useNavigation(), month = _b.month, setMonth = _b.setMonth;
    var _c = getPrevNextMonths(month, context), prevMonth = _c[0], nextMonth = _c[1];
    var onPrevClick = function (e) {
        if (!prevMonth)
            return;
        setMonth(prevMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(prevMonth);
    };
    var onNextClick = function (e) {
        if (!nextMonth)
            return;
        setMonth(nextMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(nextMonth);
    };
    var handleMonthChange = function (newMonth) {
        setMonth(newMonth);
        onMonthChange === null || onMonthChange === void 0 ? void 0 : onMonthChange(newMonth);
    };
    var prevButton = (React.createElement("button", { key: "prev", "aria-label": labelPrev(displayMonth, { locale: locale }), className: [classNames[UI.NavButton], classNames[UI.NavButtonPrev]].join(' '), style: styles[UI.NavButtonPrev], disabled: !prevMonth, onClick: dir === 'rtl' ? onNextClick : onPrevClick },
        React.createElement(IconPrev, { className: classNames[UI.NavIcon], style: styles[UI.NavIcon] })));
    var nextButton = (React.createElement("button", { key: "next", "aria-label": labelNext(displayMonth, { locale: locale }), className: [classNames[UI.NavButton], classNames[UI.NavButtonNext]].join(' '), disabled: !nextMonth, onClick: dir === 'rtl' ? onPrevClick : onNextClick, style: styles[UI.NavButtonNext] },
        React.createElement(IconNext, { className: classNames[UI.NavIcon], style: styles[UI.NavIcon] })));
    var caption = (React.createElement("div", { key: "caption", className: classNames[UI.CaptionLabel], style: styles[UI.CaptionLabel], "aria-live": "polite" }, formatCaption(displayMonth, { locale: locale })));
    var buttons = [prevButton, nextButton];
    if (dir === 'rtl')
        buttons.reverse();
    if (isFirst)
        buttons = [prevButton]; // show only the prev button
    if (isLast)
        buttons = [nextButton]; // show only the next button
    if (isBetween)
        buttons = []; // do not show buttons at all
    var nav = (React.createElement("span", { key: "nav", className: classNames[UI.Nav], style: styles[UI.Nav] }, buttons));
    return (React.createElement("div", { className: classNames[UI.Caption], style: styles[UI.Caption] }, disableNavigation ? (caption) : (React.createElement(React.Fragment, null,
        captionLayout === 'dropdown' && (React.createElement("div", { className: classNames[UI.CaptionDropdowns], style: styles[UI.CaptionDropdowns] },
            React.createElement(MonthsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth }),
            React.createElement(YearsDropdown, { onChange: handleMonthChange, displayMonth: displayMonth }))),
        captionLayout === 'buttons' &&
            numberOfMonths === 1 && [caption, nav],
        captionLayout === 'buttons' && isFirst && [nav, caption],
        captionLayout === 'buttons' && isLast && [caption, nav],
        captionLayout === 'buttons' && isBetween && caption))));
}
//# sourceMappingURL=Caption.js.map