import * as React from 'react';
import { Locale } from 'date-fns';
import { CaptionLayout, ClassNames, Components, DateRange, DayClickEventHandler, DayKeyboardEventHandler, DayMouseEventHandler, DayPickerProps, DayTouchEventHandler, Formatters, Labels, ModifierClassNames, ModifierMatchers, ModifierStyles, MonthChangeEventHandler, SelectEventHandler, SelectMode, SelectMultipleEventHandler, Styles, WeekNumberClickEventHandler } from '../../types';
import { RangeSelectionHandler } from '../useSelection/useSelectRange';
/**
 * Represent the value of the `DayPickerContext`.
 */
export interface DayPickerContextValue {
    captionLayout: CaptionLayout;
    classNames: ClassNames;
    components: Components;
    defaultMonth?: Date;
    defaultSelected?: Date | Date[] | DateRange;
    dir?: string;
    disableNavigation?: boolean;
    fixedWeeks?: boolean;
    formatters: Formatters;
    fromDate?: Date;
    labels: Labels;
    locale: Locale;
    hideHead?: boolean;
    mode: SelectMode;
    modifierClassNames: ModifierClassNames;
    modifierPrefix: string;
    modifiers: ModifierMatchers;
    modifierStyles?: ModifierStyles;
    /** This is the `month` from the initial props - use `useNavigation` hook for getting the current month. */
    month?: Date;
    numberOfMonths: number;
    onDayClick?: DayClickEventHandler;
    onDayKeyUp?: DayKeyboardEventHandler;
    onDayMouseEnter?: DayMouseEventHandler;
    onDayMouseLeave?: DayMouseEventHandler;
    onDayTouchCancel?: DayTouchEventHandler;
    onDayTouchEnd?: DayTouchEventHandler;
    onDayTouchMove?: DayTouchEventHandler;
    onDayTouchStart?: DayTouchEventHandler;
    onMonthChange?: MonthChangeEventHandler;
    onSelect?: SelectEventHandler;
    onSelectMultiple?: SelectMultipleEventHandler;
    onSelectRange?: RangeSelectionHandler;
    onWeekNumberClick?: WeekNumberClickEventHandler;
    required?: boolean;
    showOutsideDays?: boolean;
    showWeekNumber?: boolean;
    styles: Styles;
    /** Limit the navigation up to this date. Includes a parsed value from the `toMonth` and `toYear` props. */
    toDate?: Date;
    /** The today’s date used for calculations. */
    today: Date;
    /** The weekdays used for the head */
    weekdays: Date[];
}
/**
 * The DayPickerContext is a context to share props and settings within the
 * internal components. It set the defaults values, parses some props, and
 * perform one-time calculation required to render the days.
 */
export declare const DayPickerContext: React.Context<DayPickerContextValue | undefined>;
/**
 * The provider for the [[DayPickerContext]]. Must wrap the DayPicker’s root.
 */
export declare const DayPickerProvider: ({ initialProps, children }: {
    initialProps: DayPickerProps;
    children: React.ReactNode;
}) => JSX.Element;
