var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import * as React from 'react';
import english from 'date-fns/locale/en-US';
import { Day, Dropdown, Head, Row, WeekNumber } from '../../components';
import { defaultClassNames } from './defaultClassNames';
import * as formatters from './formatters';
import * as labels from './labels';
import { getWeekdays } from './utils/getWeekdays';
import { parseFromToProps } from './utils/parseFromToProps';
/**
 * The DayPickerContext is a context to share props and settings within the
 * internal components. It set the defaults values, parses some props, and
 * perform one-time calculation required to render the days.
 */
export var DayPickerContext = React.createContext(undefined);
/**
 * The provider for the [[DayPickerContext]]. Must wrap the DayPicker’s root.
 */
export var DayPickerProvider = function (_a) {
    var _b, _c, _d, _e, _f, _g;
    var initialProps = _a.initialProps, children = _a.children;
    var _h = parseFromToProps(initialProps), fromDate = _h.fromDate, toDate = _h.toDate;
    var locale = initialProps.locale || english;
    var numberOfMonths = (_b = initialProps.numberOfMonths) !== null && _b !== void 0 ? _b : 1;
    var today = (_c = initialProps.today) !== null && _c !== void 0 ? _c : new Date();
    var month = initialProps.month;
    var weekdays = getWeekdays(locale);
    // Default selection mode. If using `selected` prop, it is uncontrolled
    var mode = (_d = initialProps.mode) !== null && _d !== void 0 ? _d : 'single';
    if (initialProps.selected)
        mode = 'uncontrolled';
    // Default caption layout. If calendar navigation is unlimited it must be
    // always `buttons` as we cannot display infinite options in the dropdown.
    var captionLayout = (_e = initialProps.captionLayout) !== null && _e !== void 0 ? _e : 'buttons';
    if (!fromDate && !toDate)
        captionLayout = 'buttons';
    // Set defaults from modifiers shortcuts props
    var modifiers = initialProps.modifiers || {};
    if (initialProps.selected)
        modifiers.selected = initialProps.selected;
    if (initialProps.hidden)
        modifiers.hidden = initialProps.hidden;
    modifiers.disabled = [];
    if (initialProps.disabled) {
        if (Array.isArray(initialProps.disabled))
            modifiers.disabled = __spreadArrays(initialProps.disabled);
        else
            modifiers.disabled = [initialProps.disabled];
    }
    // Disable days before/after from/toDate
    if (fromDate)
        modifiers.disabled.push({ before: fromDate });
    if (toDate)
        modifiers.disabled.push({ after: toDate });
    var context = __assign(__assign({}, initialProps), { modifierPrefix: 'rdp-day_', numberOfMonths: numberOfMonths,
        fromDate: fromDate,
        toDate: toDate,
        captionLayout: captionLayout,
        mode: mode,
        month: month,
        today: today,
        locale: locale,
        weekdays: weekdays, modifierClassNames: (_f = initialProps.modifierClassNames) !== null && _f !== void 0 ? _f : {}, styles: (_g = initialProps.styles) !== null && _g !== void 0 ? _g : {}, modifiers: modifiers, classNames: __assign(__assign({}, defaultClassNames), initialProps.classNames), formatters: __assign(__assign({}, formatters), initialProps.formatters), labels: __assign(__assign({}, labels), initialProps.labels), components: __assign({ Day: Day, Dropdown: Dropdown, Head: Head, Row: Row, WeekNumber: WeekNumber }, initialProps.components) });
    return (React.createElement(DayPickerContext.Provider, { value: context }, children));
};
//# sourceMappingURL=DayPickerContext.js.map