import * as React from 'react';
import { addDays, addMonths, addWeeks, isSameMonth } from 'date-fns';
import { useDayPicker } from '../useDayPicker';
import { isMatch } from '../useModifiers/utils/isMatch';
import { useNavigation } from '../useNavigation';
/**
 * The focus context holds values and method to handle the focused day via
 * keyboard navigation.
 */
export var FocusContext = React.createContext(undefined);
/** Enable the FocusContext to handle the focus when navigating via keyboard. */
export var FocusProvider = function (_a) {
    var children = _a.children;
    var _b = React.useState(), focusedDay = _b[0], setDay = _b[1];
    var _c = useNavigation(), setMonth = _c.setMonth, displayMonths = _c.displayMonths;
    var _d = useDayPicker(), modifiers = _d.modifiers, numberOfMonths = _d.numberOfMonths;
    var blur = function () { return setDay(undefined); };
    var focus = function (date) { return setDay(date); };
    var switchMonth = function (date, offset) {
        if (displayMonths.some(function (m) { return isSameMonth(date, m); }))
            return;
        if (offset < 0) {
            setMonth(addMonths(date, 1 + offset));
        }
        else {
            setMonth(date);
        }
    };
    var isFocusable = function (day) {
        if (isMatch(day, modifiers.disabled))
            return false;
        return true;
    };
    var focusDayBefore = function () {
        if (!focusedDay)
            return;
        var before = addDays(focusedDay, -1);
        if (!isFocusable(before))
            return;
        setDay(before);
        switchMonth(before, numberOfMonths * -1);
    };
    var focusDayAfter = function () {
        if (!focusedDay)
            return;
        var after = addDays(focusedDay, 1);
        if (!isFocusable(after))
            return;
        setDay(after);
        switchMonth(after, numberOfMonths);
    };
    var focusDayUp = function () {
        if (!focusedDay)
            return;
        var up = addWeeks(focusedDay, -1);
        if (!isFocusable(up))
            return;
        setDay(up);
        switchMonth(up, numberOfMonths * -1);
    };
    var focusDayDown = function () {
        if (!focusedDay)
            return;
        var down = addWeeks(focusedDay, 1);
        if (!isFocusable(down))
            return;
        setDay(down);
        switchMonth(down, numberOfMonths);
    };
    var setters = {
        blur: blur,
        focus: focus,
        focusDayAfter: focusDayAfter,
        focusDayBefore: focusDayBefore,
        focusDayUp: focusDayUp,
        focusDayDown: focusDayDown
    };
    return (React.createElement(FocusContext.Provider, { value: [focusedDay, setters] }, children));
};
//# sourceMappingURL=FocusContext.js.map