import * as React from 'react';
import { DayPickerProps } from '../../types';
export declare type UseInput = {
    setMonth: React.Dispatch<React.SetStateAction<Date>>;
    setValue: React.Dispatch<React.SetStateAction<string>>;
    dayPickerProps: Partial<DayPickerProps>;
    inputProps: Partial<JSX.IntrinsicElements['input']>;
};
/**
 * Return the props for binding an input field with DayPicker.
 *
 * **Example**
 *
 * ```
 * function Example() {
 *   const { dayPickerProps, inputProps } = useInput(new Date(), 'yyyy-MM-dd');
 *   return (
 *     <>
 *       <p>
 *         Type a day or pick one from the calendar:
 *         <input {...inputProps} placeholder="YYYY-MM-DD" />
 *       </p>
 *       <DayPicker {...dayPickerProps} />
 *     </>
 *   );
 * }
 * ```
 */
export declare function useInput(initialDay: Date, formatStr: string, options?: {
    locale?: Locale;
    required: boolean;
}): UseInput;
