import { useDayPicker } from '../useDayPicker';
import { useSelection } from '../useSelection';
import { getModifierStatus } from './utils/getModifierStatus';
/** Return the status for the modifiers given the specified date */
export function useModifiers(date) {
    var context = useDayPicker();
    var selection = useSelection();
    var modifiers = Object.assign({}, context.modifiers);
    if (context.mode !== 'uncontrolled') {
        var _a = selection !== null && selection !== void 0 ? selection : {}, single = _a.single, multiple = _a.multiple, range = _a.range;
        switch (context.mode) {
            case 'range':
                if (!range.selected)
                    break;
                modifiers.selected = range.selected;
                modifiers['range-middle'] = {
                    after: range.selected.from,
                    before: range.selected.to
                };
                modifiers['range-start'] = range.selected.from;
                if (range.selected.to)
                    modifiers['range-end'] = range.selected.to;
                break;
            case 'multiple':
                if (!multiple.selected)
                    break;
                modifiers.selected = multiple.selected;
                break;
            default:
            case 'single':
                if (!single.selected)
                    break;
                modifiers.selected = single.selected;
                break;
        }
    }
    var status = getModifierStatus(date, modifiers);
    return status;
}
//# sourceMappingURL=useModifiers.js.map